@@ -1,4 +1,4 @@
-__version__ = "0.2.2"
+__version__ = "0.2.4"
 
 # module of "core"
 from npbrain import core
@@ -28,6 +28,9 @@ from npbrain import neurons
 from npbrain.neurons import HH_model
 from npbrain.neurons.HH_model import *
 
+from npbrain.neurons import input_model
+from npbrain.neurons.input_model import *
+
 from npbrain.neurons import LIF_model
 from npbrain.neurons.LIF_model import *
 
@@ -61,7 +64,9 @@ from npbrain.synapses.short_term_plasticity import *
 from npbrain import utils
 from npbrain.utils import conn
 from npbrain.utils import input_factory
+from npbrain.utils import measure
 from npbrain.utils import vis
+from npbrain.utils import run
 
 from npbrain.utils import helper
 from npbrain.utils.helper import *
