@@ -1,19 +1,18 @@
 import numpy as np
+from numba import typed, types
 
 from npbrain import profile
 from npbrain.core.neuron import Neurons
 from npbrain.core.synapse import Synapses
 from npbrain.utils import helper
 
-if profile.get_backend().startswith('numba'):
-    from numba import typed, types
-    from numba.core.dispatcher import Dispatcher
-
 __all__ = [
     'Monitor',
     'SpikeMonitor',
     'StateMonitor',
+
     'raster_plot',
+    'firing_rate',
 ]
 
 
@@ -21,24 +20,22 @@ class Monitor(object):
     """Base monitor class.
 
     """
+
     def __init__(self, target):
         self.target = target
-
-        if profile.is_numba_bk():
-            if not isinstance(self.update_state, Dispatcher):
-                self.update_state = helper.jit_function(self.update_state)
+        self.update_state = helper.autojit(self.update_state)
 
     def init_state(self, *args, **kwargs):
         raise NotImplementedError()
 
 
-
 class SpikeMonitor(Monitor):
     """Monitor class to record spikes.
 
     target : Neurons
         The neuron group to monitor.
     """
+
     def __init__(self, target):
         # check `variables`
         self.vars = ('index', 'time')
@@ -56,13 +53,12 @@ class SpikeMonitor(Monitor):
         super(SpikeMonitor, self).__init__(target)
 
     def init_state(self, length):
-        self.index = []
-        self.time = []
         if profile.is_numba_bk():
             self.index = typed.List.empty_list(types.int64)
             self.time = typed.List.empty_list(types.float64)
-        self.state = self.time
-        self.vars_idx = self.index
+        else:
+            self.index = []
+            self.time = []
 
     @staticmethod
     def update_state(obj_state, mon_time, mon_index, t):
@@ -80,6 +76,7 @@ class StateMonitor(Monitor):
     vars : str, list, tuple
         The variable need to be recorded for the ``target``.
     """
+
     def __init__(self, target, vars=None):
         # check `variables`
         if vars is None:
@@ -146,14 +143,14 @@ class StateMonitor(Monitor):
                     v = v[idx]
             else:
                 v = self.target.state[index]
-            shape = (length, ) + v.shape
+            shape = (length,) + v.shape
             state = np.zeros(shape)
             setattr(self, k, state)
             mon_states.append(state)
         self.state = tuple(mon_states)
 
 
-def raster_plot(mon):
+def raster_plot(mon, times=None):
     """Get spike raster plot which displays the spiking activity
     of a group of neurons over time.
 
@@ -161,6 +158,8 @@ def raster_plot(mon):
     ----------
     mon : Monitor
         The monitor which record spiking activities.
+    times : None, numpy.ndarray
+        The time steps.
 
     Returns
     -------
@@ -170,10 +169,70 @@ def raster_plot(mon):
     if isinstance(mon, StateMonitor):
         elements = np.where(mon.spike > 0.)
         index = elements[1]
-        time = mon.spike_time[elements]
+        if hasattr(mon, 'spike_time'):
+            time = mon.spike_time[elements]
+        else:
+            assert times is not None
+            time = times[elements[0]]
     elif isinstance(mon, SpikeMonitor):
         index = np.array(mon.index)
         time = np.array(mon.time)
     else:
         raise ValueError
     return index, time
+
+
+def firing_rate(mon, width, window='gaussian'):
+    """Calculate the mean firing rate over in a neuron group.
+
+    This method is adopted from Brian2.
+
+    The firing rate in trial :math:`k` is the spike count :math:`n_{k}^{sp}`
+    in an interval of duration :math:`T` divided by :math:`T`:
+
+    .. math::
+
+        v_k = {n_k^{sp} \\over T}
+
+    Parameters
+    ----------
+    mon : StateMonitor
+        The monitor which record spiking activities.
+    width : int, float
+        The width of the ``window`` in millisecond.
+    window : str
+        The window to use for smoothing. It can be a string to chose a
+        predefined window:
+
+        - `flat`: a rectangular,
+        - `gaussian`: a Gaussian-shaped window.
+
+        For the `Gaussian` window, the `width` parameter specifies the
+        standard deviation of the Gaussian, the width of the actual window
+        is `4 * width + dt`.
+        For the `flat` window, the width of the actual window
+        is `2 * width/2 + dt`.
+
+    Returns
+    -------
+    rate : numpy.ndarray
+        The population rate in Hz, smoothed with the given window.
+    """
+    # rate
+    assert hasattr(mon, 'spike'), 'Must record the "spike" of the neuron group to get firing rate.'
+    rate = np.sum(mon.spike, axis=1)
+
+    # window
+    dt = profile.get_dt()
+    if window == 'gaussian':
+        width1 = 2 * width / dt
+        width2 = int(np.round(width1))
+        window = np.exp(-np.arange(-width2, width2 + 1) ** 2 / (width1 ** 2 / 2))
+    elif window == 'flat':
+        width1 = int(width / 2 / dt) * 2 + 1
+        window = np.ones(width1)
+    else:
+        raise ValueError('Unknown window type "{}".'.format(window))
+    window = np.float_(window)
+
+    return np.convolve(rate, window / sum(window), mode='same')
