@@ -9,7 +9,7 @@ from npbrain.core.synapse import Synapses
 from npbrain.utils.helper import Dict
 
 __all__ = [
-    'Network'
+    'Network',
 ]
 
 
@@ -17,13 +17,14 @@ class Network(object):
     """The main simulation controller in ``NumpyBrain``.
 
     ``Network`` handles the running of a simulation. It contains a set of
-    objects that are added with `~Network.add`. The `~Network.run` method
+    objects that are added with `add()`. The `run()` method
     actually runs the simulation. The main loop runs according to user add
     orders. The objects in the `Network` are accessible via their names, e.g.
     `net.name` would return the `object` (including neurons, synapses, and
     monitors) with this name.
 
     """
+
     def __init__(self, *args, **kwargs):
         # store and neurons and synapses
         self.neurons = []
@@ -34,6 +35,10 @@ class Network(object):
         self._objsets = Dict()
         self.objects = []
 
+        # store states of objects and synapses
+        self._neuron_states = None
+        self._synapse_states = None
+
         # record the current step
         self.current_time = 0.
 
@@ -101,7 +106,7 @@ class Network(object):
         for input_ in inputs:
             # get "receiver", "input", "duration"
             if len(input_) == 2:
-                obj, Iext  = input_
+                obj, Iext = input_
                 dur = (0, duration)
             elif len(input_) == 3:
                 obj, Iext, dur = input_
@@ -128,9 +133,12 @@ class Network(object):
             size = np.shape(Iext)[0]
             run_length = dur[1] - dur[0]
             if size != run_length:
-                if size == 1: Iext = np.ones(obj.num) * Iext
-                elif size == obj.num: Iext = Iext
-                else: raise ValueError('Wrong size of inputs for', obj)
+                if size == 1:
+                    Iext = np.ones(obj.num) * Iext
+                elif size == obj.num:
+                    Iext = Iext
+                else:
+                    raise ValueError('Wrong size of inputs for', obj)
                 fixed_inputs.append([obj, Iext, dur])
             else:
                 input_size = np.size(Iext[0])
@@ -145,6 +153,22 @@ class Network(object):
                 no_inputs.append(neu)
         return iterable_inputs, fixed_inputs, no_inputs
 
+    def _input(self, run_idx, iterable_inputs, fixed_inputs, no_inputs):
+        # inputs
+        for receiver, inputs, dur in iterable_inputs:
+            if dur[0] <= run_idx <= dur[1]:
+                obj_idx = run_idx - dur[0]
+                receiver.state[-1] = inputs[obj_idx]
+            else:
+                receiver.state[-1] = 0.
+        for receiver, inputs, dur in fixed_inputs:
+            if dur[0] <= run_idx <= dur[1]:
+                receiver.state[-1] = inputs
+            else:
+                receiver.state[-1] = 0.
+        for receiver in no_inputs:
+            receiver.state[-1] = 0.
+
     def _step(self, t, run_idx):
         for obj in self.objects:
             if isinstance(obj, Synapses):
@@ -161,7 +185,7 @@ class Network(object):
             else:
                 raise ValueError
 
-    def run(self, duration, report=False, inputs=()):
+    def run(self, duration, report=False, inputs=(), repeat=False):
         """Runs the simulation for the given duration.
 
         Parameters
@@ -170,15 +194,18 @@ class Network(object):
             The amount of simulation time to run for.
         report : bool
             Report the progress of the simulation.
+        repeat : bool
+            Whether repeat run this model. If `repeat=True`, every time
+            call this method will initialize the object state.
         inputs : list, tuple
             The receivers, external inputs and durations.
         """
-        # checking
-        # --------
+        # 1. checking
+        # ------------
         self._check_run_order()
 
-        # initialization
-        # -----------------
+        # 2. initialization
+        # ------------------
 
         # time
         dt = profile.get_dt()
@@ -189,47 +216,60 @@ class Network(object):
         for mon in self.monitors:
             mon.init_state(run_length)
 
-        # format external inputs
-        # -------------------------
+        # neurons
+        if repeat:
+            if self._neuron_states is None:
+                self._neuron_states = [neu.state.copy() for neu in self.neurons]
+            else:
+                for neu, state in zip(self.neurons, self._neuron_states):
+                    neu.state = state.copy()
+
+        # synapses
+        if repeat:
+            if self._synapse_states is None:
+                self._synapse_states = []
+                for syn in self.synapses:
+                    state = tuple(st.copy() for st in syn.state)
+                    self._synapse_states.append([state, syn.var_index.copy()])
+            else:
+                for syn, (state, var_index) in zip(self.synapses, self._synapse_states):
+                    syn.state = tuple(st.copy() for st in state)
+                    syn.var_index = var_index.copy()
+
+        # 3. format external inputs
+        # --------------------------
         iterable_inputs, fixed_inputs, no_inputs = self._format_inputs_and_receiver(inputs, duration)
 
-        # run
+        # 4. run
         # ---------
+
+        # initialize
         if report:
+            t0 = time.time()
+        self._input(0, iterable_inputs, fixed_inputs, no_inputs)
+        self._step(ts[0], 0)
+
+        # record time
+        if report:
+            print('Compilation used {:.4f} ms.'.format(time.time() - t0))
+            print("Start running ...")
             report_gap = int(run_length / 10)
             t0 = time.time()
 
-        for run_idx in range(run_length):
+        # run
+        for run_idx in range(1, run_length):
             t = ts[run_idx]
-
-            # inputs
-            for receiver, inputs, dur in iterable_inputs:
-                if dur[0] <= run_idx <= dur[1]:
-                    obj_idx = run_idx - dur[0]
-                    receiver.state[-1] = inputs[obj_idx]
-                else:
-                    receiver.state[-1] = 0.
-            for receiver, inputs, dur in fixed_inputs:
-                if dur[0] <= run_idx <= dur[1]:
-                    receiver.state[-1] = inputs
-                else:
-                    receiver.state[-1] = 0.
-            for receiver in no_inputs:
-                receiver.state[-1] = 0.
-
-                # run objects orderly
+            self._input(run_idx, iterable_inputs, fixed_inputs, no_inputs)
             self._step(t, run_idx)
-
-            # report
             if report and ((run_idx + 1) % report_gap == 0):
                 percent = (run_idx + 1) / run_length * 100
                 print('Run {:.1f}% using {:.3f} s.'.format(percent, time.time() - t0))
         if report:
-            print('Done. ')
+            print('Simulation is done. ')
 
-        # Finally
-        # -------
-        self.current_time += duration
+        # 5. Finally
+        # -----------
+        self.current_time = duration
 
     def run_time(self):
         """Get the time points of the network.
@@ -240,5 +280,3 @@ class Network(object):
             The running time-steps of the network.
         """
         return np.arange(0, self.current_time, profile.get_dt())
-
-
