@@ -1,10 +1,8 @@
 import numpy as np
 
+from npbrain.utils.helper import autojit
 from npbrain import profile
 
-if profile.is_numba_bk():
-    import numba as nb
-
 __all__ = [
     'ode_generator',
     'forward_Euler', 'explicit_Euler',
@@ -84,13 +82,13 @@ def forward_Euler(f, dt):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         return y0 + dt * f(y0, t, *args)
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # euler-end
 
 
@@ -122,15 +120,15 @@ def rk2(f, dt, beta=2 / 3):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         k1 = f(y0, t, *args)
         k2 = f(y0 + beta * dt * k1, t + beta * dt, *args)
         return y0 + dt * ((1 - 1 / (2 * beta)) * k1 + 1 / (2 * beta) * k2)
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # rk2-end
 
 
@@ -154,6 +152,8 @@ def explicit_midpoint_Euler(f, dt):
         The one-step numerical integration function.
     """
     return rk2(f, dt, beta=0.5)
+
+
 # modified_Euler-end
 
 
@@ -177,16 +177,16 @@ def rk3(f, dt):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         k1 = f(y0, t, *args)
         k2 = f(y0 + dt / 2 * k1, t + dt / 2, *args)
         k3 = f(y0 - dt * k1 + 2 * dt * k2, t + dt, *args)
         return y0 + dt / 6 * (k1 + 4 * k2 + k3)
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # rk3-end
 
 
@@ -209,6 +209,7 @@ def rk4(f, dt):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         k1 = f(y0, t, *args)
         k2 = f(y0 + dt / 2 * k1, t + dt / 2, *args)
@@ -216,10 +217,9 @@ def rk4(f, dt):
         k4 = f(y0 + dt * k3, t + dt, *args)
         return y0 + dt / 6 * (k1 + 2 * k2 + 2 * k3 + k4)
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # rk4-end
 
 
@@ -243,6 +243,7 @@ def rk4_alternative(f, dt):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         k1 = f(y0, t, *args)
         k2 = f(y0 + dt / 3 * k1, t + dt / 3, *args)
@@ -250,10 +251,9 @@ def rk4_alternative(f, dt):
         k4 = f(y0 + dt * k1 - dt * k2 + dt * k3, t + dt, *args)
         return y0 + dt / 8 * (k1 + 3 * k2 + 3 * k3 + k4)
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # rk4_alternative-end
 
 
@@ -276,6 +276,7 @@ def backward_Euler(f, dt, epsilon=1e-12):
     func : callable
         The one-step numerical integration function.
     """
+
     def int_f(y0, t, *args):
         y1 = y0 + dt * f(y0, t, *args)
         y2 = y0 + dt * f(y1, t, *args)
@@ -284,10 +285,9 @@ def backward_Euler(f, dt, epsilon=1e-12):
             y2 = y0 + dt * f(y1, t, *args)
         return y2
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # backward_Euler-end
 
 
@@ -323,10 +323,9 @@ def trapezoidal_rule(f, dt, epsilon=1e-12):
             y2 = y0 + dt / 2 * (dy0 + f(y1, t + dt, *args))
         return y2
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
+    return autojit(int_f)
+
 
-    return int_f
 # trapezoidal_rule-end
 
 
@@ -371,10 +370,4 @@ def exp_euler_o2(f, dt, factor_zero_order, factor_one_order):
         y0 = f(y0, t, *args)
         return y0 * a + b
 
-    if profile.is_numba_bk():
-        int_f = nb.jit(**profile.get_numba_profile())(int_f)
-
-    return int_f
-
-
-
+    return autojit(int_f)
