@@ -1,9 +1,7 @@
 import numpy as np
 
 from npbrain import profile
-
-if profile.is_numba_bk():
-    import numba as nb
+from npbrain.utils.helper import autojit
 
 __all__ = [
     'sde_generator',
@@ -96,10 +94,9 @@ def Euler_method(f, g, dt=None):
             dg = dt_sqrt * g * dW
             return y0 + df + dg
 
-    if profile.is_numba_bk():
-        int_fg = nb.jit(**profile.get_numba_profile())(int_fg)
+    return autojit(int_fg)
+
 
-    return int_fg
 # Euler_method-end
 
 
@@ -151,10 +148,9 @@ def Milstein_dfree_Ito(f, g, dt=None):
             y1 = y0 + df + dg + 0.5 * (g_n_bar - g) * (dW * dW * dt_sqrt - dt_sqrt)
             return y1
 
-    if profile.is_numba_bk():
-        int_fg = nb.jit(**profile.get_numba_profile())(int_fg)
+    return autojit(int_fg)
+
 
-    return int_fg
 # Milstein_dfree_Ito-end
 
 
@@ -211,10 +207,9 @@ def Heun_method2(f, g, dt=None):
             y1 = y0 + 0.5 * (df0 + df1) + dg
             return y1
 
-    if profile.is_numba_bk():
-        int_fg = nb.jit(**profile.get_numba_profile())(int_fg)
+    return autojit(int_fg)
+
 
-    return int_fg
 # Heun_method2-end
 
 
@@ -270,10 +265,9 @@ def Heun_method(f, g, dt=None):
             y1 = y0 + df + dg
             return y1
 
-    if profile.is_numba_bk():
-        int_fg = nb.jit(**profile.get_numba_profile())(int_fg)
+    return autojit(int_fg)
+
 
-    return int_fg
 # Heun_method-end
 
 
@@ -323,8 +317,5 @@ def Milstein_dfree_Stra(f, g, dt=None):
             y1 = y0 + df + dg
             return y1
 
-    if profile.is_numba_bk():
-        int_fg = nb.jit(**profile.get_numba_profile())(int_fg)
-
-    return int_fg
+    return autojit(int_fg)
 # Milstein_dfree_Stra-end
