@@ -1,6 +1,3 @@
-from math import ceil
-from typing import Union
-
 import numpy as np
 
 from npbrain import profile
@@ -13,10 +10,10 @@ __all__ = [
     'Synapses',
 ]
 
-
 synapse_no = 0
 
 
+@helper.autojit
 def record_conductance(syn_state, var_index, g):
     """Record the conductance of the synapses.
 
@@ -41,12 +38,6 @@ def record_conductance(syn_state, var_index, g):
     syn_state[1][delay_idx] = g
 
 
-if profile.is_numba_bk():
-    from numba.core.dispatcher import Dispatcher
-
-    record_conductance = helper.jit_function(record_conductance)
-
-
 def format_delay(delay, dt=None):
     """Format the given delay and get the delay length.
 
@@ -66,7 +57,7 @@ def format_delay(delay, dt=None):
         delay_len = 1
     elif isinstance(delay, (int, float)):
         dt = profile.get_dt() if dt is None else dt
-        delay_len = int(ceil(delay / dt)) + 1
+        delay_len = int(np.ceil(delay / dt)) + 1
     else:
         raise ValueError()
     return delay_len
@@ -144,6 +135,7 @@ class Synapses(object):
     kwargs : dict
         Parameters of the synapses.
     """
+
     def __init__(self, **kwargs):
         if 'kwargs' in kwargs:
             kwargs.pop('kwargs')
@@ -162,20 +154,18 @@ class Synapses(object):
             def f1(syn_state, var_index, neu_state):
                 output_idx = var_index[-2]
                 neu_state[-1] += syn_state[output_idx[0]][output_idx[1]]
+
             self.output_synapse = f1
 
         if 'collect_spike' not in kwargs:
             def f2(syn_state, pre_neu_state, post_neu_state):
                 syn_state[0][-1] = pre_neu_state[-3]
+
             self.collect_spike = f2
 
-        if profile.is_numba_bk():
-            if not isinstance(self.update_state, Dispatcher):
-                self.update_state = helper.jit_function(self.update_state)
-            if not isinstance(self.output_synapse, Dispatcher):
-                self.output_synapse = helper.jit_function(self.output_synapse)
-            if not isinstance(self.collect_spike, Dispatcher):
-                self.collect_spike = helper.jit_function(self.collect_spike)
+        self.update_state = helper.autojit(self.update_state)
+        self.output_synapse = helper.autojit(self.output_synapse)
+        self.collect_spike = helper.autojit(self.collect_spike)
 
         # check `name`
         if 'name' not in kwargs:
@@ -198,7 +188,7 @@ class Synapses(object):
         # "g" is the "delay_idx"
         # 'g_post' is the "output_idx"
         default_variables = [('pre_spike', (0, -1)), ('g', (1, self.delay_len - 1)),
-                             ('g_post', (1, 0)),]
+                             ('g_post', (1, 0)), ]
         for k, _ in default_variables:
             if k in self.var2index:
                 raise ValueError('"{}" is a pre-defined variable, '
