@@ -4,12 +4,15 @@ are implemented in the ``NumpyBrain`` framework. For each neuron model,
 one of the most important elements is ``update_state()`` function.
 """
 
-# HH.py
+# HH_model.py
 from npbrain.neurons.HH_model import *
 
-# Izhikevich.py
+# input_model.py
+from npbrain.neurons.input_model import *
+
+# Izhikevich_model.py
 from npbrain.neurons.Izhikevich_model import *
 
-# LIF.py
+# LIF_model.py
 from npbrain.neurons.LIF_model import *
 
