@@ -9,6 +9,12 @@ from npbrain.utils.input_factory import *
 # helper.py
 from npbrain.utils.helper import *
 
+# measure.py
+from npbrain.utils.measure import *
+
+# run.py
+from npbrain.utils.run import *
+
 # vis.py
 # from npbrain.utils.vis import *
 
