@@ -1,25 +1,37 @@
-import types
+import copy
 import functools
+import types
+
+import numba as nb
 import numpy as np
 
-from npbrain.profile import is_numba_bk
 from npbrain.profile import get_numba_profile
+from npbrain.profile import is_numba_bk
 
-if is_numba_bk():
-    import numba as nb
 
 __all__ = [
+    # parameter helpers
     'check_params',
+
+    # function helpers
     'jit_function',
     'jit_lambda',
     'autojit',
-    'clip',
-    'copy_func',
+    'func_copy',
+
+    # data structure
     'Dict',
     'default_dict',
     'ddict',
+
+    # others
+    'clip',
 ]
 
+##############################
+# parameter helpers
+##############################
+
 
 def check_params(kwargs):
     """Check the ``kwargs`` parameters.
@@ -35,6 +47,10 @@ def check_params(kwargs):
     assert len(kwargs) == 0, "No arguments about: {}".format(list(kwargs.keys()))
 
 
+##############################
+# function helpers
+##############################
+
 def jit_function(f):
     """Generate ``numba`` JIT functions.
 
@@ -107,50 +123,7 @@ def autojit(func):
     return func
 
 
-def clip(a, a_min, a_max):
-    """Reproduce the ``clip`` function in NumPy.
-
-    Clip (limit) the values in an array.
-
-    Given an interval, values outside the interval are clipped to
-    the interval edges.  For example, if an interval of ``[0, 1]``
-    is specified, values smaller than 0 become 0, and values larger
-    than 1 become 1.
-
-    Equivalent to but faster than ``np.maximum(a_min, np.minimum(a, a_max))``.
-    No check is performed to ensure ``a_min < a_max``.
-
-    Parameters
-    ----------
-    a : array_like
-        Array containing elements to clip.
-    a_min : scalar or array_like or None
-        Minimum value. If None, clipping is not performed on lower
-        interval edge. Not more than one of `a_min` and `a_max` may be
-        None.
-    a_max : scalar or array_like or None
-        Maximum value. If None, clipping is not performed on upper
-        interval edge. Not more than one of `a_min` and `a_max` may be
-        None. If `a_min` or `a_max` are array_like, then the three
-        arrays will be broadcasted to match their shapes.
-
-    Returns
-    -------
-    clipped_array : ndarray
-        An array with the elements of `a`, but where values
-        < `a_min` are replaced with `a_min`, and those > `a_max`
-        with `a_max`.
-    """
-    a = np.maximum(a, a_min)
-    a = np.minimum(a, a_max)
-    return a
-
-
-if is_numba_bk():
-    clip = autojit(clip)
-
-
-def copy_func(f):
+def func_copy(f):
     """Based on http://stackoverflow.com/a/6528148/190597 (Glenn Maynard)"""
     g = types.FunctionType(f.__code__, f.__globals__,
                            name=f.__name__,
@@ -161,6 +134,10 @@ def copy_func(f):
     return g
 
 
+##############################
+# data structure
+##############################
+
 class Dict(dict):
     def __init__(__self, *args, **kwargs):
         object.__setattr__(__self, '__parent', kwargs.pop('__parent', None))
@@ -223,6 +200,19 @@ class Dict(dict):
     def __delattr__(self, name):
         del self[name]
 
+    def copy(self):
+        return copy.copy(self)
+
+    def deepcopy(self):
+        return copy.deepcopy(self)
+
+    def __deepcopy__(self, memo):
+        other = self.__class__()
+        memo[id(self)] = other
+        for key, value in self.items():
+            other[copy.deepcopy(key, memo)] = copy.deepcopy(value, memo)
+        return other
+
     def to_dict(self):
         base = {}
         for key, value in self.items():
@@ -275,9 +265,56 @@ class Dict(dict):
 
 
 def default_dict(args_update, *args, **kwargs):
-    args = dict(*args, **kwargs)
+    args = Dict(*args, **kwargs)
     args.update(args_update)
     return args
 
 
-ddict = default_dict
\ No newline at end of file
+ddict = default_dict
+
+
+##############################
+# other helpers
+##############################
+
+@autojit
+def clip(a, a_min, a_max):
+    """Reproduce the ``clip`` function in NumPy.
+
+    Clip (limit) the values in an array.
+
+    Given an interval, values outside the interval are clipped to
+    the interval edges.  For example, if an interval of ``[0, 1]``
+    is specified, values smaller than 0 become 0, and values larger
+    than 1 become 1.
+
+    Equivalent to but faster than ``np.maximum(a_min, np.minimum(a, a_max))``.
+    No check is performed to ensure ``a_min < a_max``.
+
+    Parameters
+    ----------
+    a : array_like
+        Array containing elements to clip.
+    a_min : scalar or array_like or None
+        Minimum value. If None, clipping is not performed on lower
+        interval edge. Not more than one of `a_min` and `a_max` may be
+        None.
+    a_max : scalar or array_like or None
+        Maximum value. If None, clipping is not performed on upper
+        interval edge. Not more than one of `a_min` and `a_max` may be
+        None. If `a_min` or `a_max` are array_like, then the three
+        arrays will be broadcasted to match their shapes.
+
+    Returns
+    -------
+    clipped_array : ndarray
+        An array with the elements of `a`, but where values
+        < `a_min` are replaced with `a_min`, and those > `a_max`
+        with `a_max`.
+    """
+    a = np.maximum(a, a_min)
+    a = np.minimum(a, a_max)
+    return a
+
+
+
