@@ -3,6 +3,7 @@ Visualization toolkit.
 """
 
 import matplotlib.pyplot as plt
+from matplotlib import rcParams
 
 from matplotlib.gridspec import GridSpec
 
@@ -10,6 +11,9 @@ from npbrain.core.monitor import raster_plot
 
 __all__ = [
     'get_figure',
+
+    'mpl_style1',
+
     'plot_value',
     'plot_potential',
     'plot_raster',
@@ -23,6 +27,34 @@ def get_figure(n_row, n_col, len_row=3, len_col=6):
     gs = GridSpec(n_row, n_col, figure=fig)
     return fig, gs
 
+###############################
+# plotting style
+###############################
+
+
+def mpl_style1(fontsize=22, axes_edgecolor='white', figsize='5,4', lw=1):
+    rcParams['text.latex.preamble'] = [r"\usepackage{amsmath, lmodern}"]
+    params = {
+        'text.usetex': True,
+        'font.family': 'lmodern',
+        # 'text.latex.unicode': True,
+        'text.color': 'black',
+        'xtick.labelsize': fontsize - 2,
+        'ytick.labelsize': fontsize - 2,
+        'axes.labelsize': fontsize,
+        'axes.labelweight': 'bold',
+        'axes.edgecolor': axes_edgecolor,
+        'axes.titlesize': fontsize,
+        'axes.titleweight': 'bold',
+        'pdf.fonttype': 42,
+        'ps.fonttype': 42,
+        'axes.grid': False,
+        'axes.facecolor': 'white',
+        'lines.linewidth': lw,
+        "figure.figsize": figsize,
+    }
+    rcParams.update(params)
+
 
 ###############################
 # Neuron and Synapse plotting
